pub struct Sym { /* private fields */ }Expand description
The string symbol type for Boa.
This symbol type is internally a NonZeroUsize, which makes it pointer-width in size and it’s
optimized so that it can occupy 1 pointer width even in an Option type.
Implementations
Sourceimpl Sym
impl Sym
Sourcepub fn is_reserved_identifier(self) -> bool
pub fn is_reserved_identifier(self) -> bool
Checks if this symbol is one of the reserved identifiers of the ECMAScript
specification, excluding await and yield
Sourcepub fn is_strict_reserved_identifier(self) -> bool
pub fn is_strict_reserved_identifier(self) -> bool
Checks if this symbol is one of the strict reserved identifiers of the ECMAScript specification.
Sourceimpl Sym
impl Sym
Sourcepub const INSTANCEOF: Self
pub const INSTANCEOF: Self
Symbol for the “instanceof” string.
Sourcepub const IMPLEMENTS: Self
pub const IMPLEMENTS: Self
Symbol for the “implements” string.
Sourcepub const EMPTY_STRING: Self
pub const EMPTY_STRING: Self
Symbol for the “” string.
Sourcepub const CONSTRUCTOR: Self
pub const CONSTRUCTOR: Self
Symbol for the “constructor” string.
Sourcepub const DEFAULT_EXPORT: Self
pub const DEFAULT_EXPORT: Self
Symbol for the “*default*” string.
Sourcepub const ASYNCDISPOSE: Self
pub const ASYNCDISPOSE: Self
Symbol for the “asyncDispose” string.