ToInternedString

Trait ToInternedString 

pub trait ToInternedString {
    // Required method
    fn to_interned_string(&self, interner: &Interner) -> String;
}
Converts a given element to a string using an interner.

Required Methods

fn to_interned_string(&self, interner: &Interner) -> String

Converts a given element to a string using an interner.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors